@@ -93,7 +93,7 @@ class Selenium(Scraper):
                 return False
         else:
             try:
-                return element.find_elements(by=By.XPATH, value=path)
+                return len(element.find_elements(by=By.XPATH, value=path)) > 0
 
             except NoSuchElementException:
                 return False
